@@ -1,11 +1,7 @@
 import sqlite3
 
-def teste(n):
-    return True
 
-
-
-def createTable(conn):
+def createTable(dbName):
     name = input("Insira o nome da tabela: ")
     pk = 0
     sql = "CREATE TABLE "+name+" ( "
@@ -29,17 +25,17 @@ def createTable(conn):
             print("ERROR")
             break
 
-        newLines = int(input("Deseja inserir outra linha: [1] SIM, [2] NÃO? "))
 
         if pk == 0:
             linePk = int(input("Esse dado é uma chave primaria: [1] SIM, [2] NÃO? "))
             
             if linePk == 1:
                 pk = 1
-                linePk = "PRIMARY KEY,"
+                linePk = " PRIMARY KEY, "
             else:
                 linePk = ", "
 
+        newLines = int(input("Deseja inserir outra linha: [1] SIM, [2] NÃO? "))
         if newLines == 2:
             linePk = ""
         
@@ -50,4 +46,11 @@ def createTable(conn):
             break
     
 
-    return(sql)
\ No newline at end of file
+    conn = sqlite3.connect(dbName)
+    cursor = conn.cursor()
+    cursor.execute(sql)
+
+    conn.close()
+    
+
+    return(True)
\ No newline at end of file
